pilas.motores.motor_qt.Actor

Package pilas :: Package motores :: Module motor_qt :: Class Actor |
[hide private]
[frames] | no frames]

# Class Actor

source code

    object --+
             |
     BaseActor --+
                 |
                Actor

Instance Methods | [hide private]
__init__(self, imagen="sin_imagen.png", x=0, y=0) x.__init__(...) initializes x; see help(type(x)) for signature | source code
definir_imagen(self, imagen) | source code
obtener_imagen(self) | source code
dibujar(self, painter) | source code
Inherited from `BaseActor`: `definir_centro`, `definir_escala`, `definir_escala_x`, `definir_escala_y`, `definir_posicion`, `definir_rotacion`, `definir_transparencia`, `obtener_escala`, `obtener_posicion`, `obtener_rotacion`, `obtener_transparencia`, `set_espejado` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, imagen="sin_imagen.png", x=0, y=0) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)